![Alt text](https://github.com/frisbro303/SignDNE/blob/43ff8aeeb91cf7bbd23d0f08f5aa8e1123ad189d/teeth-demo.png)

# SignDNE
[![Test package](https://github.com/frisbro303/SignDNE/actions/workflows/test.yml/badge.svg)](https://github.com/frisbro303/SignDNE/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/frisbro303/SignDNE/graph/badge.svg?token=H5S4TW7139)](https://codecov.io/gh/frisbro303/SignDNE)

A Python package for calculating the shape complexity metric ariaDNE and its sign-oriented extension.

## Documentation
`SignDNE` can be used as a Python library and as a standalone command line interface.

Documentation for `SignDNE` is found in [docs.md](https://github.com/frisbro303/signDNE_Python/blob/main/docs.md), which includes a section specifically for the [command line interface](https://github.com/frisbro303/signDNE_Python/blob/main/docs.md#command-line-interface).

## Installation
![PyPI - Version](https://img.shields.io/pypi/v/signDNE)

The recommended installation method is to install the latest tagged release with `pip`:
```bash
pip install signDNE
```
Alternatively, you can install the latest development version of `SignDNE` by running:
```bash
pip install git+https://github.com/frisbro303/SignDNE
```

## License
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

This software is licensed under the GPL-3.0 License. See the [LICENSE](https://github.com/frisbro303/SignDNE/blob/2347bf47a35affe612ac8d60e64805a3f1891951/LICENSE) file for details. 

